<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
    >
      <div class="query-box">
        <div class="query-box__left">
          <el-form-item label="" prop="pharmacyName">
            <el-input
              v-model="queryParams.pharmacyName"
              placeholder="请输入药房名称"
              clearable
              size="small"
              @keyup.enter.native="handleQuery"
              style="width:160px"
            />
          </el-form-item>
          <el-form-item label="" prop="communityId">
            <el-select
              v-model="queryParams.communityId"
              placeholder="请选择医共体"
              clearable
              size="small"
              @change="handleComId"
              style="width:160px"
            >
              <el-option
                v-for="item in cimmunity"
                :key="item.id"
                :label="item.name"
                :value="item.id"
                :disabled="item.state == 1 ? false : true"
              >
              </el-option>
            </el-select>
          </el-form-item>
          <el-form-item label="" prop="mechanismId">
            <el-select
              style="width:160px"
              v-model="queryParams.mechanismId"
              placeholder="请选择医疗机构"
              clearable
              size="small"
              @change="handleMechanismId"
            >
              <el-option
                v-for="item in mechanismArr"
                :key="item.id"
                :label="item.name"
                :value="item.id"
                :disabled="item.state == 1 ? false : true"
              >
              </el-option>
            </el-select>
          </el-form-item>
          <el-form-item label="" prop="deptId">
            <!-- <el-input
              v-model="queryParams.deptId"
              placeholder="请选择科室病区"
              clearable
              size="small"
              @keyup.enter.native="handleQuery"
            /> -->

            <el-select
              style="width:160px"
              v-model="queryParams.deptId"
              placeholder="请选择科室病区"
            >
              <el-option
                v-for="item in deptListArr"
                :key="item.id"
                :label="item.name"
                :value="item.id"
              >
              </el-option>
            </el-select>
          </el-form-item>
          <el-form-item>
            <el-button
              type="primary"
              icon="el-icon-search"
              size="mini"
              @click="handleQuery"
              >搜索</el-button
            >
            <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
              >重置</el-button
            >
            <el-button
              type="primary"
              plain
              icon="el-icon-plus"
              size="mini"
              @click="handleAdd"
              v-hasPermi="['pharmacy:mechanism:add']"
              >新增</el-button
            >
          </el-form-item>
        </div>
      </div>
    </el-form>

    <!-- <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['pharmacy:mechanism:add']"
          >新增</el-button
        >
      </el-col>

    </el-row> -->

    <el-table
      v-loading="loading"
      :data="mechanismList"
      @selection-change="handleSelectionChange"
      :border="true"
    >
      <el-table-column type="index" width="55" align="center" label="序号" />
      <!-- <el-table-column label="id" align="center" prop="id" /> -->
      <el-table-column
        label="药房名称"
        align="center"
        prop="pharmacyName"
        width="140"
      />
      <!-- <el-table-column
        label="医共体"
        align="center"
        prop="communityId"
        width="140"
      /> -->
      <el-table-column
        label="医疗机构"
        align="center"
        prop="mechanismName"
        width="140"
      />
      <!-- <el-table-column label="科室" align="center" prop="deptId" width="140" /> -->
      <el-table-column label="科室病区" align="center" prop="deptName" />
      <el-table-column label="创建人" align="center" prop="createBy" />
      <el-table-column label="修改时间" align="center" prop="updateTime">
        <!-- <template slot-scope="scope">
          <span>{{
            parseTime(
              scope.row.updateTime || scope.row.createTime,
              "{y}-{m}-{d}"
            )
          }}</span>
        </template> -->
      </el-table-column>
      <el-table-column label="状态" align="center" prop="state">
        <template slot-scope="scope">
          <dict-tag :options="stateOptions" :value="scope.row.state" />
        </template>
      </el-table-column>
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
        width="140"
      >
        <template slot-scope="scope">
          <el-button
            v-if="scope.row.state == '0'"
            size="mini"
            type="primary"
            style="width: 40px"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['pharmacy:mechanism:edit']"
            >作废</el-button
          >
          <!-- <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['pharmacy:mechanism:remove']"
            >删除</el-button
          > -->
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改医疗机构与药房对照管理对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="120px">
        <el-form-item label="药房名称" prop="pharmacyId">
          <!-- <el-input v-model="form.pharmacyId" placeholder="请输入药房" /> -->
          <el-cascader
            v-model="form.pharmacyId"
            :options="MedicalPharmacyList"
            :props="{ checkStrictly: true, emitPath: false }"
            :show-all-levels="false"
            placeholder="请选择药房"
            clearable
            style="width: 100%"
          ></el-cascader>
        </el-form-item>
        <el-form-item label="医共体" prop="communityId">
          <!-- <el-input v-model="form.communityId" placeholder="请输入医共体id" /> -->
          <el-select
            v-model="form.communityId"
            placeholder="请选择医共体"
            clearable
            size="small"
            @change="handleChangeCommunity"
            style="width: 100%"
          >
            <el-option
              v-for="(item, index) in cimmunity"
              :key="index"
              :label="item.name"
              :value="item.id"
              :disabled="item.state == 1 ? false : true"
            >
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="医疗机构" prop="mechanismId">
          <el-select
            v-model="form.mechanismId"
            placeholder="请选择医疗机构"
            clearable
            size="small"
            @change="handlechangeMechanidm"
            style="width: 100%"
          >
            <el-option
              v-for="item in mechanism"
              :key="item.id"
              :label="item.name"
              :value="item.id"
              :disabled="item.state == 1 ? false : true"
            >
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="科室病区" prop="deptId">
          <!-- <el-input v-model="form.deptId" placeholder="请输入科室" /> -->
          <el-select
            v-model="form.deptId"
            placeholder="请选择科室病区"
            style="width: 100%"
          >
            <el-option
              v-for="item in deptList"
              :key="item.id"
              :label="item.name"
              :value="item.id"
            >
            </el-option>
          </el-select>
        </el-form-item>
        <!-- <el-form-item label="科室" prop="del">
          <el-input v-model="form.del" placeholder="请输入科室" />
        </el-form-item> -->
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listMechanism,
  getMechanism,
  delMechanism,
  addMechanism,
  updateMechanism,
  exportMechanism,
} from "@/api/pharmacy/mechanism";

import { listMedicalPharmacy } from "@/api/pharmacy/MedicalPharmacy";
import { listMedicalMechanism } from "@/api/medical/mechanism";
import { getByMechanismId } from "@/api/medical/dept";
import { listMechanismId } from "@/api/medical/mechanism";
import { listCommunity } from "@/api/medical/community";
import { listDept } from "@/api/medical/dept";
export default {
  name: "Mechanism",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 医疗机构与药房对照管理表格数据
      mechanismList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        pharmacyName: null,
        communityId: null,
        mechanismId: null,
        deptId: null,
        del: null,
      },
      stateOptions: [
        { dictLabel: "正常", dictValue: "0" },
        { dictLabel: "作废", dictValue: "1" },
      ],
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        pharmacyId: [
          { required: true, message: "药房名称必填", trigger: "blur" },
        ],
        communityId: [
          { required: true, message: "医共体必填", trigger: "blur" },
        ],
        mechanismId: [
          { required: true, message: "医疗机构必填", trigger: "blur" },
        ],
      },
      MedicalPharmacyList: [], //药房列表
      cimmunity: [], //医共体列表
      mechanism: [], //医疗机构列表
      deptList: [], //科室列表
      mechanismArr: [],
      deptListArr: [],
    };
  },
  created() {
    this.getList();
    this.getMedicalPharmacy();
    this.getCommunityList();
    // this.getMechanismListArr();
    // this.getListDeptArr();
    // this.getListDept();
    // this.getMechanismList();
    // this.getDicts("sys_normal_disable").then((response) => {
    //   this.stateOptions = response.data;
    // });
  },
  computed: {
    getName: function () {
      return this.form.pharmacyId;
    },
  },
  watch: {
    getName: {
      handler(val, oldVal) {
        //console.log("b.c: " + val, oldVal);
      },
      deep: true,
    },
  },
  methods: {
    /** 查询医疗机构与药房对照管理列表 */
    getList() {
      this.loading = true;
      listMechanism(this.queryParams).then((response) => {
        this.mechanismList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },

    /** 查询药房列表 */
    getMedicalPharmacy() {
      this.loading = true;
      listMedicalPharmacy(this.queryParams).then((response) => {
        this.MedicalPharmacyList = this.handleTree(
          response.data,
          "id",
          "parentId"
        );
        _readNodes(this.MedicalPharmacyList);
        function _readNodes(nodes = [], arr = []) {
          for (let item of nodes) {
            item.label = item.name;
            item.value = item.id;
            if (item.children && item.children.length)
              _readNodes(item.children, arr);
          }
        }

        this.loading = false;
      });
    },
    /** 查询医共体列表 */
    getCommunityList() {
      listCommunity().then((response) => {
        this.cimmunity = response.rows;
      });
    },
    /** 通过医共体id查询机构 **/
    handleChangeCommunity() {
      if (this.form.communityId) {
        this.getMechanismList(this.form.communityId);
        this.form.mechanismId = null;
        this.form.deptId = null;
      }
    },
    handleComId(e) {
      //console.log(e);
      this.getMechanismListArr(e);
    },
    getMechanismListArr(id) {
      this.queryParams.mechanismId = ''
      this.queryParams.deptId = ''
      listMedicalMechanism(id).then((response) => {
        this.mechanismArr = response.data.filter(v => v.communityId == id);
      });
    },
    /** 查询医疗机构名称 **/
    getMechanismList(id) {
      listMechanismId(id).then((response) => {
        this.mechanism = response.data;
        this.mechanismId = null;
      });
    },
    /** 通过医疗机构查询科室 **/
    handlechangeMechanidm() {
      if (this.form.mechanismId) {
        // this.getMedicalPharmacy(this.form.mechanismId);
        this.getListDept(this.form.mechanismId);
        this.form.deptId = null;
      }
    },
    handleMechanismId(e) {
      this.queryParams.deptId = ''
      this.getListDeptArr(e);
    },
    getListDeptArr(id) {
      listDept(id).then((response) => {
        this.deptListArr = response.rows.filter(v => v.communityId == id);
        // //console.log(response.rows, "999");
      });
    },
    /** 查询科室名称 */
    getListDept(id) {
      getByMechanismId(id).then((response) => {
        this.deptList = response.data;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        pharmacyId: null,
        communityId: null,
        mechanismId: null,
        deptId: null,
        createTime: null,
        updateTime: null,
        createBy: null,
        updateBy: null,
        del: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加医疗机构与药房对照管理";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      // this.reset();
      const id = row.id || this.ids;
      this.$confirm("确定需要作废选中的数据吗？", "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(() => {
          const parmes = {
            id,
            state: 1,
          };
          updateMechanism(parmes).then((response) => {
            this.getList();
            // this.msgSuccess("修改成功");
          });
        })
        .catch(() => {});
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.id != null) {
            updateMechanism(this.form).then((response) => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addMechanism(this.form).then((response) => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$confirm("确定需要删除已选数据吗？", "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(function () {
          return delMechanism(ids);
        })
        .then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm("是否确认导出所有医疗机构与药房对照管理数据项?", "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(() => {
          this.exportLoading = true;
          return exportMechanism(queryParams);
        })
        .then((response) => {
          this.download(response.msg);
          this.exportLoading = false;
        })
        .catch(() => {});
    },
  },
};
</script>
